@@ -85,6 +85,13 @@ public:
     void removeTagFromCandidateList(QString category, QString tag);
     void checkProposedTagData(QPair<QString, QString> tagData, ResizableFrame *areaToExclude) const;
     void areaChanged();
+    bool positionableTagAvailable(const QString &category, const QString &tag) const;
+    QSet<QString> positionedTags(const QString &category) const;
+    /**
+     * @return A list of all ResizableFrame objects on the current image
+     */
+    QList<ResizableFrame*> areas() const;
+    ListSelect* listSelectForCategory( const QString &category);
 
 protected slots:
     void slotRevert();
