@@ -17,12 +17,10 @@
 */
 #include "ImageDB.h"
 #include "XMLDB/Database.h"
-#include <klocale.h>
+#include <KLocalizedString>
 #include <qfileinfo.h>
-#include <QList>
 #include "Browser/BrowserWidget.h"
 #include "DB/CategoryCollection.h"
-#include <QProgressBar>
 #include <qapplication.h>
 #include "NewImageFinder.h"
 #include <DB/MediaCount.h>
