@@ -20,6 +20,7 @@
 
 #include <QCheckBox>
 #include <QComboBox>
+#include <QDebug>
 #include <QDialogButtonBox>
 #include <QFileDialog>
 #include <QGroupBox>
@@ -519,8 +520,8 @@ QString HTMLDialog::includeSelections() const
 void HTMLDialog::populateThemesCombo()
 {
     QStringList dirs = QStandardPaths::locateAll(
-                QStandardPaths::GenericDataLocation,
-                QString::fromLocal8Bit("kphotoalbum/themes/"),
+                QStandardPaths::DataLocation,
+                QString::fromLocal8Bit("themes/"),
                 QStandardPaths::LocateDirectory
                 );
     int i = 0;
