@@ -19,25 +19,27 @@
 #include "DeleteDialog.h"
 
 #include <QVBoxLayout>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <qcheckbox.h>
 #include <qlabel.h>
 #include <qlayout.h>
+#include <QDialogButtonBox>
+#include <QPushButton>
 #include "Utilities/DeleteFiles.h"
 
 using namespace MainWindow;
 
 DeleteDialog::DeleteDialog( QWidget* parent )
-    : KDialog(parent)
+    : QDialog(parent)
     , m_list()
 {
     setWindowTitle( i18n("Removing items") );
-    setButtons( Cancel|User1 );
-    setButtonText( User1,i18n("OK") );
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
 
     QWidget* top = new QWidget;
     QVBoxLayout* lay1 = new QVBoxLayout( top );
-    setMainWidget( top );
+    mainLayout->addWidget(top);
 
 
     m_label = new QLabel;
@@ -52,7 +54,10 @@ DeleteDialog::DeleteDialog( QWidget* parent )
     m_deleteFromDb = new QRadioButton;
     lay1->addWidget( m_deleteFromDb );
 
-     connect( this, SIGNAL(user1Clicked()), this, SLOT(deleteImages()) );
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &DeleteDialog::deleteImages);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &DeleteDialog::reject);
+    mainLayout->addWidget(buttonBox);
 }
 
 int DeleteDialog::exec(const DB::FileNameList& list)
@@ -87,7 +92,7 @@ int DeleteDialog::exec(const DB::FileNameList& list)
     m_deleteFile->setEnabled( someFileExists );
     m_deleteFromDb->setChecked( !someFileExists );
 
-    return KDialog::exec();
+    return QDialog::exec();
 }
 
 void DeleteDialog::deleteImages()
